[wiki目录](./README.md)

# 目录结构

本篇介绍 apollo 的目录结构及其内在的一套规范。

## go语言中的包（package）

在 go 语言中，一个包就是一个文件夹，一个文件夹中的所有文件属于同一个包（存在 `*_test` 特例，便于写测试用例）。如果习惯了 python 或者 ruby 的开发的同学，可能很容易编写出“循环依赖”的代码。

当然，暴露出循环依赖的问题并不意味着大家不精通 go 语言开发，因为“循环依赖”的问题更像是一个“分层失误”的设计问题。

## 模块与分层

在实际的项目开发过程中，如果项目庞大业务复杂，项目负责人都会自然而然地对项目进行模块划分，定义好模块间的协议后把每个模块的开发任务下放给不同的开发小组；在实际的编码过程中，为了保证代码的可维护性，开发者都会自然而然地对代码逻辑进行模块划分。模块划分看似是显而易见的道理，尤其模块的划分与编程语言 package（java、go等）、module（ruby、python等）里的规范十分契合，也引导大家向着模块划分来思考问题。

只是，在模块划分的过程中，大家很容易忽略*分层*的意识：即各个模块间隐含着某种层次关系。如下图所示，假如越靠近下层模块功能越基础，那么将只允许上层的模块依赖下层的模块（允许跨层依赖），不能出现横向依赖，也不能出现下层对上层的依赖。有了上面的约束，各个模块之间就能很好地进行配合了。

```bash
###########################
# 层4     模块g   模块h
###########################
# 层3  模块d  模块e  模块f
###########################
# 层2      模块c
###########################
# 层1   模块a   模块b
###########################
```

按照 go 语言中一个目录属于一个包（package），一个*包*包含的是功能范畴基本一致的逻辑（等同于模块）；为了让各个包默契配合，那么各包之间也理应存在*层次*关系。


## apollo 项目中的层次关系

为了表征各包，我们以目录的相对路径表示各包，比如 `/configs/initializer` 表示包 `github.com/chalvern/apollo/configs/initializer`。

为了编译及调试的便利，apollo 把 `main.go` 放在了项目的最外层。根据 go 语言规范，`main.go` 是逻辑的总入口，相当于它依赖所有的模块，因为它太特殊，因此这里不再单独列出。

下面是对各个包内容的简介：

*高层* -> *底层* 的顺序

* `/cmds`，命令包，属于命令入口，初始化各组件（日志、数据库等），注册主程序和子程序等
* `/cmds/server`，服务包，注册各个服务，如果一个应用有多个 web 服务，则可以考虑在此包内逐一注册
* `/cmds/sub`，子命令包，注册各个子命令，比如 apollo 中的数据迁移（migration）子命令

* `/app`，应用包，是 apollo 的主 web 服务的入口，包含了 mvc 模块的初始化、路由注册等
* `/app/router`，路由包，用于定义路由转发
* `/app/interceptors`，中间件包，用于定义一些公共的中间件，比如统一鉴权中间件

* `/app/controller`，控制器层，路由转发到对应的控制器层进行具体逻辑的执行
* `/app/views`，视图，go模板文件，不属于 go 原生包。
* `/app/helper`，帮助包，定义并注册一些在 go 模板文件中可能会用到的*模板函数*

* `/app/service`, 服务层，为了简化控制器层的代码逻辑，同时增强模型层的逻辑而刻意存在的夹层（非必须，但是存在更佳）
* `/app/model`，模型层，定义基础的结构体，指定与 数据表 的对应关系，同时定义各模型增删改查的基本逻辑

* `/app/pubsub`，异步任务包，主要用来执行异步任务

* `/configs/constants`，常量包，存放项目中所有可能的常量，便于统一管理
* `/configs/initializer`，初始化包，各组件的初始化逻辑均放此包，比如 `mysql`、`viper(配置)`、`sugar(日志)`等

除了上面的包，还存在几个特殊的工具包：

* `/migrations/template`，迁移模板包，用来生成迁移的模板，后面可能会考虑单独拿出去独立成库
* `/migrations`，迁移包，各个模型的迁移放置在此包；仿照 rubyonrails 中的设计，迁移依次叠加，保证模型的一致

* `/tools`，工具包，子包中包含一些可以独立成库的工具类的源码

## 小结
本小结主要介绍了提到了 模块和分层 的概念，高层次的模块可以依赖低层次的模块，反之不可；并按照从高到底的层次陈列出 apollo 的目录结构及各个包的主要职责。

## 参考

* [从 Clean-Architecture 谈架构原理及其应用](https://jingwei.link/2018/12/31/thinking-of-architecture.html) 之前写的关于整洁架构的文章，核心就是分层
* 